@@ -1,4 +1,4 @@
-# Copyright 2018-2022 contributors to the OpenLineage project
+# Copyright 2018-2023 contributors to the OpenLineage project
 # SPDX-License-Identifier: Apache-2.0
 
 import logging
@@ -6,13 +6,15 @@ import typing
 from typing import Optional
 
 import attr
+from openlineage.client.serde import Serde
+
 if typing.TYPE_CHECKING:
     from requests import Session
     from requests.adapters import HTTPAdapter
 
 from openlineage.client.run import RunEvent
 from openlineage.client.transport import Transport, get_default_factory
-from openlineage.client.transport.http import HttpTransport, HttpConfig
+from openlineage.client.transport.http import HttpConfig, HttpTransport
 
 
 @attr.s
@@ -66,6 +68,10 @@ class OpenLineageClient:
         if not self.transport:
             log.error("Tried to emit OpenLineage event, but transport is not configured.")
         else:
+            if log.isEnabledFor(logging.DEBUG):
+                log.debug(
+                    f"OpenLineageClient will emit event {Serde.to_json(event).encode('utf-8')}"
+                )
             self.transport.emit(event)
 
     @classmethod
