@@ -1,10 +1,10 @@
-# Copyright 2018-2022 contributors to the OpenLineage project
+# Copyright 2018-2023 contributors to the OpenLineage project
 # SPDX-License-Identifier: Apache-2.0
+
 from enum import Enum
 from typing import Dict, List, Optional
 
 import attr
-
 from openlineage.client.constants import DEFAULT_PRODUCER
 from openlineage.client.utils import RedactMixin
 
@@ -376,6 +376,10 @@ class ProcessingEngineRunFacet(BaseFacet):
     name: str = attr.ib()
     openlineageAdapterVersion: str = attr.ib()
 
+    @staticmethod
+    def _get_schema() -> str:
+        return SCHEMA_URI + "#/definitions/ProcessingEngineRunFacet"
+
 
 @attr.s
 class ExtractionError(BaseFacet):
@@ -390,3 +394,7 @@ class ExtractionErrorRunFacet(BaseFacet):
     totalTasks: int = attr.ib()
     failedTasks: int = attr.ib()
     errors: List[ExtractionError] = attr.ib()
+
+    @staticmethod
+    def _get_schema() -> str:
+        return SCHEMA_URI + "#/definitions/ExtractionErrorRunFacet"
