@@ -1,12 +1,12 @@
-# Copyright 2018-2022 contributors to the OpenLineage project
-# SPDX-License-Identifier: Apache-2.0.
+# Copyright 2018-2023 contributors to the OpenLineage project
+# SPDX-License-Identifier: Apache-2.0
+
 import logging
+from typing import TYPE_CHECKING, Dict, Optional
 from urllib.parse import urljoin
 
 import attr
 
-from typing import Optional, Dict, TYPE_CHECKING
-
 if TYPE_CHECKING:
     from requests import Session
     from requests.adapters import HTTPAdapter
@@ -117,8 +117,6 @@ class HttpTransport(Transport):
 
     def emit(self, event: RunEvent):
         event = Serde.to_json(event)
-        if log.isEnabledFor(logging.DEBUG):
-            log.debug(f"Sending openlineage event {event}")
         resp = self.session.post(
             urljoin(self.url, self.endpoint),
             event,
